@@ -1,4 +1,7 @@
 require(adimpro)
+if(Sys.getenv("ImageMagick")==""){
+cat("Please install ImageMagick\n")
+} else {
 #
 #     smoothing images
 #
@@ -48,3 +51,4 @@ graphics.off()
 if(toupper(z)!="N"){
 rm(img,img0,imghat,imghat2, z)
 }
+}
\ No newline at end of file
